==> not-so-tuf-0.3.2.tar.gz: not-so-tuf-0.3.2/not_so_tuf/__init__.py <==
# The MIT License (MIT)
#
# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import logging
import os
import sys
import traceback

logger = logging.getLogger(__name__)


class NotSoTuf(object):
    """There are 2 ways to load config.  The first was is during
    object initialization. The second way is later with :meth:`update_config`

    Examples are shown below::

        DEBUG = True
        SECRET_KEY = 'development key'
        app.config.from_object(__name__)
        Config(object):
            APP_NAME = "NST"

            APP_DATA_DIR = None

            UPDATE_URL = http://www.test-nst.com/updates

        app = NotSoTuf(Config())

        app = NotSoTuf()
        app.update_config(Config())

    Kwargs:
        import_name (str): used to get current directory

        cfg_obj (instance): object with config attributes
    """
    def __init__(self, import_name=None, cfg_obj=None):
        if import_name is None:
            raise UpdaterError(u'You have to pass __name__ to Updater',
                               expected=True)
        self.import_name = import_name
        self.real_path = os.path.dirname(os.path.abspath(self.import_name))
        self.config = Config()
        self.config['APP_DIR'] = self.real_path
        if cfg_obj:
            self.update_config(cfg_obj)

    def update_config(self, obj):
        """Proxy method to update internal config dict

        Args:
            obj (instance): config object
        """
        self.config.from_object(obj)
        if self.config.get('DEV_DATA_DIR', None) is None:
            logger.info('Using default directory')
            self.config['DEV_DATA_DIR'] = os.path.join(self.real_path)
        if self.config.get('APP_NAME', None) is None:
            self.config['APP_NAME'] = 'Not_So_TUF'


class Config(dict):
    """Works exactly like a dict but provides ways to fill it from files
    or special dictionaries.  There are two common patterns to populate the
    config.

    You can define the configuration options in the
    module that calls :meth:`from_object`.  It is also possible to tell it
    to use the same module and with that provide the configuration values
    just before the call.

    Loading from modules, only uppercase keys are added to the config.
    This makes it possible to use lowercase values in the config file for
    temporary values that are not added to the config or to define the config
    keys in the same file that implements the application.
    """

    def __init__(self, defaults=None):
        super(Config, self).__init__(defaults or {})

    def from_object(self, obj):
        """Updates the values from the given object

        Args:
            obj (instance): Object with config attributes

        Objects are classes.

        Just the uppercase variables in that object are stored in the config.
        Example usage::

            from yourapplication import default_config
            app.config.from_object(default_config)
        """
        for key in dir(obj):
            if key.isupper():
                self[key] = getattr(obj, key)

    def __repr__(self):
        return '<%s %s>' % (self.__class__.__name__, dict.__repr__(self))


class STDError(Exception):
    def __init__(self, msg, tb=None, expected=False, cause=None):
        """ tb, if given, is the original traceback *so that it can be
        printed out*.

        If expected is set, this is a normal error message and most
        likely not a bug in Not_So_TUF.
        """
        if not expected:
            msg = msg + (u'; please report this issue on https://github.com'
                         '/JohnyMoSwag/Not-So-TUF/issues')
        super(Exception, self).__init__(msg)

        self.traceback = tb
        self.exc_info = sys.exc_info()  # preserve original exception
        self.cause = cause

    def format_traceback(self):
        if self.traceback is None:
            return None
        return u''.join(traceback.format_tb(self.traceback))


class ClientException(STDError):
    """Raised for Client exceptions"""
    def __init__(self, *args, **kwargs):
        super(ClientException, self).__init__(*args, **kwargs)


class ConfigException(STDError):
    """Raised for Config exceptions"""
    def __init__(self, *args, **kwargs):
        super(ConfigException, self).__init__(*args, **kwargs)


class FileDownloaderError(STDError):
    """Raised for File Downloader exceptions"""
    def __init__(self, *args, **kwargs):
        super(PackageHandlerError, self).__init__(*args, **kwargs)


class KeyHandlerError(STDError):
    """Raised for Key Handler exceptions"""
    def __init__(self, *args, **kwargs):
        super(KeyHandlerError, self).__init__(*args, **kwargs)


class NotSoTufError(STDError):
    """Raised for Framework exceptions"""
    def __init__(self, *args, **kwargs):
        super(NotSoTufError, self).__init__(*args, **kwargs)


class PackageHandlerError(STDError):
    """Raised for Package Handler exceptions"""
    def __init__(self, *args, **kwargs):
        super(PackageHandlerError, self).__init__(*args, **kwargs)


class UpdaterError(STDError):
    """Raised for Updater exceptions"""
    def __init__(self, *args, **kwargs):
        super(UpdaterError, self).__init__(*args, **kwargs)


class UploaderError(STDError):
    """Raised for Uploader exceptions"""
    def __init__(self, *args, **kwargs):
        super(UploaderError, self).__init__(*args, **kwargs)

==> not-so-tuf-0.4.0.tar.gz: not-so-tuf-0.4.0/not_so_tuf/__init__.py <==
# The MIT License (MIT)
#
# Copyright (c) 2014 JohnyMoSwag <johnymoswag@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import logging
import os

logger = logging.getLogger(__name__)

from not_so_tuf.client import Client
from not_so_tuf.config import Config
from not_so_tuf.downloader import FileDownloader
from not_so_tuf.filecrypt import FileCrypt
from not_so_tuf.key_handler import KeyHandler
from not_so_tuf.package_handler import PackageHandler
from not_so_tuf.patcher import Patcher
from not_so_tuf.uploader import Uploader


class NotSoTuf(object):
    """There are 2 ways to load config.  The first was is during
    object initialization. The second way is later with :meth:`update_config`

    Examples are shown below::

        DEBUG = True
        SECRET_KEY = 'development key'
        app.config.from_object(__name__)
        Config(object):
            APP_NAME = "NST"

            APP_DATA_DIR = None

            UPDATE_URL = http://www.test-nst.com/updates

        app = NotSoTuf(Config())

        app = NotSoTuf()
        app.update_config(Config())

    Kwargs:
        import_name (str): used to get current directory

        cfg_obj (instance): object with config attributes
    """
    def __init__(self, import_name=None, cfg_obj=None):
        if import_name is None:
            raise UpdaterError(u'You have to pass __name__ to Updater',
                               expected=True)
        self.import_name = import_name
        self.real_path = os.path.dirname(os.path.abspath(self.import_name))
        self.config = Config()
        self.config['APP_DIR'] = self.real_path
        if cfg_obj:
            self.update_config(cfg_obj)

    def update_config(self, obj):
        """Proxy method to update internal config dict

        Args:
            obj (instance): config object
        """
        self.config.from_object(obj)
        if self.config.get('DEV_DATA_DIR', None) is None:
            logger.info('Using default directory')
            self.config['DEV_DATA_DIR'] = os.path.join(self.real_path)
        if self.config.get('APP_NAME', None) is None:
            self.config['APP_NAME'] = 'Not_So_TUF'
